==> haskell-timezone-series-0.1.9-11-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-timezone-series.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 timezone-series
version:              0.1.9
visibility:           public
id:                   timezone-series-0.1.9-BOaWIUAL0b77nThbCcBvws
key:                  timezone-series-0.1.9-BOaWIUAL0b77nThbCcBvws
license:              BSD-3-Clause
copyright:            Copyright (c) 2010-2018 Yitzchak Gale. All rights reserved.
maintainer:           yitz@sefer.org
author:               Yitzchak Gale
homepage:             http://projects.haskell.org/time-ng/
synopsis:             Enhanced timezone handling for Data.Time
description:
    This package endows Data.Time, from the time
    package, with several data types and functions
    for enhanced processing of timezones. For one way
    to create timezone series, see the timezone-olson
    (<http://hackage.haskell.org/package/timezone-olson>)
    and timezone-olson-th
    (<http://hackage.haskell.org/package/timezone-olson-th>)
    packages.

category:             Data
abi:                  6c00b3c0d746f31a5d002d48e923a964
exposed:              True
exposed-modules:      Data.Time.LocalTime.TimeZone.Series
hidden-modules:       Data.Time.LocalTime.TimeZone.Internal.TimeVersion
import-dirs:          /usr/lib/ghc-9.0.1/site-local/timezone-series-0.1.9
library-dirs:         /usr/lib/ghc-9.0.1/site-local/timezone-series-0.1.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/timezone-series-0.1.9
hs-libraries:         HStimezone-series-0.1.9-BOaWIUAL0b77nThbCcBvws
depends:              base-4.15.0.0 deepseq-1.4.5.0 time-1.9.3
haddock-interfaces:
    /usr/share/doc/haskell-timezone-series/html/timezone-series.haddock

haddock-html:         /usr/share/doc/haskell-timezone-series/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-timezone-series-0.1.13-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-timezone-series.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 timezone-series
version:              0.1.13
visibility:           public
id:                   timezone-series-0.1.13-8hy5SgZJJLXGTkGPNLHG0s
key:                  timezone-series-0.1.13-8hy5SgZJJLXGTkGPNLHG0s
license:              BSD-3-Clause
copyright:            Copyright (c) 2010-2021 Yitzchak Gale. All rights reserved.
maintainer:           yitz@sefer.org
author:               Yitzchak Gale
homepage:             http://projects.haskell.org/time-ng/
synopsis:             Enhanced timezone handling for Data.Time
description:
    This package endows Data.Time, from the time
    package, with several data types and functions
    for enhanced processing of timezones. For one way
    to create timezone series, see the timezone-olson
    (<http://hackage.haskell.org/package/timezone-olson>)
    and timezone-olson-th
    (<http://hackage.haskell.org/package/timezone-olson-th>)
    packages.

category:             Data
abi:                  3f1c89edc00706912a3acda443f06763
exposed:              True
exposed-modules:      Data.Time.LocalTime.TimeZone.Series
import-dirs:          /usr/lib/ghc-9.0.2/site-local/timezone-series-0.1.13
library-dirs:         /usr/lib/ghc-9.0.2/site-local/timezone-series-0.1.13
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-timezone-series
hs-libraries:         HStimezone-series-0.1.13-8hy5SgZJJLXGTkGPNLHG0s
depends:              base-4.15.1.0 deepseq-1.4.5.0 time-1.9.3
haddock-interfaces:
    /usr/share/doc/haskell-timezone-series/html/timezone-series.haddock

haddock-html:         /usr/share/doc/haskell-timezone-series/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
